Install Schevo on Mac OS X — libschevo 3.2.4 documentation

### Navigation

- index
- next |
- previous |
- libschevo 3.2.4 documentation »
- Getting Started with Schevo »

# Install Schevo on Mac OS X

Below, we describe in detail how to install Schevo for Mac OSX. The instructions have been tested on the following operating systems:

- Mac OSX 10.4.10 on Intel-chip Based Mac

## Notes on running Python

Unless you change your PATH environment variable, do not run Python by running `python`, as that will invoke the system-installed Python, which is version 2.3.5 in OSX 10.4.

Instead, run `python2.5` as shown in examples below.

## Install Python packages

1. At the Python 2.5.1 release page, download the disk image (`dmg`) file for Python. For instance, the file at the time of this writing is `python-2.5.1-macosx.dmg`.

2. Open the disk image.
3. Open the installer (`mpkg`) file from the disk image.
4. Follow the steps to complete installation, using default values at each stage.

If you do not have administrator privileges, request to have an administrator install Python for you.

## Download workingenv and set up an environment for Schevo

1. Download workingenv.py to your home directory.

2. If it doesn’t exist, create a directory named `env` in your home directory using a terminal or your favorite file manager.

3. In a terminal, create the environment:

       $ python2.5 ~/workingenv.py ~/env/schevo

## Activate the Schevo environment

In a terminal, run these commands to activate the Schevo environment and change to its source directory:

    $ source ~/env/schevo/bin/activate

You’ll see `(schevo)` added to your prompt. Repeat this section every time you want to access the `schevo` working environment.

## Installing Schevo

In a command prompt, use EasyInstall to install the latest release of Schevo:

    easy_install Schevo

## What to do after Schevo is installed

Take a tour by choosing one of the Schevo tutorials.

### Navigation

- index
- next |
- previous |
- libschevo 3.2.4 documentation »
- Getting Started with Schevo »